@@ -13,11 +13,12 @@
 #include "gettextheader.h"
 #include "prefs_lokalize.h"
 #include "project.h"
+#include "version.h"
+
+#include <KLocalizedString>
 
 #include <QSet>
 
-#include <klocalizedstring.h>
-
 const char *const *processes()
 {
     static const char *const processes[] = {"translation", "review", "approval"};
