@@ -22,15 +22,6 @@
 #include "qamodel.h"
 #include "tmmanager.h"
 
-#include <QDBusArgument>
-#include <QDir>
-#include <QElapsedTimer>
-#include <QFileInfo>
-#include <QLocale>
-#include <QStringBuilder>
-#include <QTime>
-#include <QTimer>
-
 #include <KIO/Global>
 #include <KIO/JobTracker>
 #include <KJob>
@@ -39,6 +30,16 @@
 #include <KMessageBox>
 #include <KNotification>
 
+#include <QDir>
+#include <QElapsedTimer>
+#include <QFileInfo>
+#include <QFileSystemWatcher>
+#include <QLocale>
+#include <QSqlDatabase>
+#include <QStringBuilder>
+#include <QTime>
+#include <QTimer>
+
 QString getMailingList()
 {
     QString lang = QLocale::system().name();
