@@ -12,12 +12,11 @@
 #define PROJECT_H
 
 #include "projectbase.h"
-#include <QFileSystemWatcher>
-#include <QList>
-#include <QVector>
 
 class ProjectModel;
 class ProjectLocal;
+class QFileSystemWatcher;
+
 namespace GlossaryNS
 {
 class Glossary;
