@@ -14,12 +14,12 @@
 #include "tmentry.h"
 
 #include <QRunnable>
-#include <QThreadPool>
-
-#include <QMutex>
-#include <QSqlDatabase>
 #include <QString>
+
+class QMutex;
+class QSqlDatabase;
 class QSqlQuery;
+class QThreadPool;
 
 /**
  * Translation Memory classes. see initDb() function for the database scheme
