@@ -10,25 +10,21 @@
 #ifndef TMTAB_H
 #define TMTAB_H
 
+#include "config-lokalize.h"
 #include "lokalizetabpagebase.h"
 #include "pos.h"
 
-#include <kmainwindow.h>
-
 #include <QMutex>
-#include <QScreen>
-#include <QSqlDatabase>
 #include <QSqlQueryModel>
 
-class KXMLGUIClient;
-class QComboBox;
-class QTreeView;
-class QSortFilterProxyModel;
-class QCheckBox;
-
-class QaView;
-class Ui_QueryOptions;
 class TMResultsSortFilterProxyModel;
+class Ui_QueryOptions;
+class KXMLGUIClient;
+class QCheckBox;
+class QComboBox;
+class QSortFilterProxyModel;
+class QTreeView;
+class QaView;
 
 namespace TM
 {
@@ -48,17 +44,13 @@ public:
     explicit TMTab(QWidget *parent);
     ~TMTab() override;
 
-    void hideDocks() override
-    {
-    }
-    void showDocks() override
-    {
-    }
     KXMLGUIClient *guiClient() override
     {
         return (KXMLGUIClient *)this;
     }
+#if HAVE_DBUS
     QString dbusObjectPath();
+#endif
     int dbusId()
     {
         return m_dbusId;
